@@ -4,7 +4,7 @@ import numpy as np
 TradeLIST = []
 AnalysisLIST = []
 
-from DirectoryFormulas import Directories
+from DirectoryFormulas import *
 
 def StatisticsBacktesting(Cerebro, margin, Mininbars = 0):
     for s in Cerebro:
